grab.error: классы исключений — Grab 0.6.30 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »

# grab.error: классы исключений

class `grab.error.` `GrabError`

  All custom Grab exception should be children of that class.

class `grab.error.` `GrabNetworkError`

  Raises in case of network error.

class `grab.error.` `GrabTimeoutError`

  Raises when configured time is outed for the request.

  In curl transport it is CURLE_OPERATION_TIMEDOUT (28)

class `grab.error.` `GrabMisuseError`

  Indicates incorrect usage of grab API.

class `grab.error.` `DataNotFound`

  Raised when it is not possible to find requested data.

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »